
th = thermo('H2');

% Thermo properties
T_up = 24.45;            % Tank temperature [K]
Ta = 273.15+15;         % Ambient temperature [K]
T_down = Ta;            % Downstream temperature [K] 
p_up = 10e5;             % Liquid H2 tank pressure [Pa]
p_down = 1e5;           % Downstream pressure [Pa]
%rho = 70.84;            % Density [kg/m3]
visc = 13.92e-6;        % Viscosity [Pa*s]

w = 0.228;              % Mass flow [kg/s] 

[ps,vl,vv] = th.saturation(T_up);
th.Tvcalc(T_up,vl);
s0 = th.s;
P = th.p

% State in tank
p0 = 3e5;
th.pscalc(p0,s0);
rho = 2/th.v;
v0 = th.v;
C_p_start = th.cp/2;

% State at P1
p1 = 3.6e5;
h1 = th.h;
th.phcalc(p1,h1);
T1 = th.T;
rho1 = 2/th.v;
v1 = th.v;

% State at P2
p2 = 3.55e5;
h2 = th.h;
th.phcalc(p2, h2);
T2 = th.T;
rho2 = 2/th.v;

% State at P3
p3 = 3.457e5;
h3 = th.h;
th.phcalc(p3, h3);
T3 = th.T;
rho3 = 2/th.v;
[ps,vl,vv] = th.saturation(T3);
v_fg3 = (vv-vl)/2;

% State at P4
p4 = 3.368e5;
h4 = th.h;
th.phcalc(p4, h4);
T4 = th.T;
rho4 = 2/th.v;
[ps,vl,vv] = th.saturation(T4);
v_fg4 = (vv-vl)/2;
th.Tvcalc(T4,vl);
Hl = th.h;
C_p = th.cp/2;
th.Tvcalc(T4,vv);
Hv = th.h;
dH = (Hv - Hl)/2;


%th.Tpcalc(T_up, p_up);

% Liquid H2 tank properties
tank.wallmass = 500;     % kg
tank.cp_wall = 0.01;     % J/kg/K 
tank.V = 5;              % m3
tank.Area = 10;          % m2
tank.heatcoeff = 0;      % W/m2/K


% Ship tank properties
tank.wallmass = 500;     % kg
tank.cp_wall = 0.01;     % J/kg/K 
tank.V = 5;              % m3
tank.Area = 10;          % m2
tank.heatcoeff = 0;      % W/m2/K


% Pipe properties
D = 0.05;               % Pipe diameter [m]
d = 0.04;               % Small pipe diameter [m]
epsilon = 0.015;        % Absolute roughness
L = 42;                 % Pipe length [m]

% Pipe losses
bend = 1;
valve = 10;
exit = 1;
enter = 10;
diameter_change = (1-d^2/D^2)^2;
minor_loss = bend + valve + exit + enter;


% Pipe pressure loss calculation
RR = epsilon/(D*10^3);                          % Relative roughness
v = (4*w)/(pi*D^2*rho);                         % Velocity [m/s]
Re = (rho*v*D)/visc;                            % Reynolds number
f_d = 0.0055*(1+(2e4*RR+(10^6/Re))^(1/3));      % Darcy friction factor with Moody approximation
h_l = (minor_loss*v*2)/(2*9.81);

d_P = ((8*f_d*L*w^2)/(pi^2*D*5*rho*9.81)) + (h_l*rho*9.81);             % Darcy Weiback eq
delta_p = rho*((v^2/2)*((1+(f_d*L)/D)+minor_loss));      % Pressure loss in pipes

% Hose loss
globe_valve = 6.5;
minor_loss_hose = 2*globe_valve;
% Hose pressure loss calculation
RR = epsilon/(D*10^3);                          % Relative roughness
v = (4*w)/(pi*D^2*rho);                         % Velocity [m/s]
Re = (rho*v*D)/visc;                            % Reynolds number
f_d = 0.0055*(1+(2e4*RR+(10^6/Re))^(1/3));      % Darcy friction factor with Moody approximation
L_hose = 5;

delta_p = rho*((v^2/2)*((1+(f_d*L_hose)/D)+minor_loss_hose));      % Pressure loss in pipes






