# -*- coding: utf-8 -*-
"""
Created on Fri Apr  8 10:21:37 2022

@author: nilsj
"""
import openpyxl as opx
import numpy as np
import matplotlib.pyplot as plt

'Mass workbook'
workbook = opx.load_workbook(filename = 'C:/Users/nilsj/Desktop/Master/Bunkering of liquid hydrogen/Rawdata_FFI/Cumulative_pressure/Test_1/Test_1_cumulative.xlsx')

sheet = workbook.active

'Time'
for t in sheet.iter_cols(min_row=250,
                           max_row=1900,
                           min_col=1,
                           max_col=1,
                           values_only=True):
    v = t
    t = list(t)

'Mass data'
for m in sheet.iter_cols(min_row =250,
                           max_row=1900,
                           min_col=14,
                           max_col=14,
                           values_only=True):
    w = m
    m = list(m)
    
for P in sheet.iter_cols(min_row =250,
                           max_row=1900,
                           min_col=10,
                           max_col=10,
                           values_only=True):
    P = list(P)


'Polynom fit'
m_dot = np.polyfit(t, m, 1)
print(m_dot)

mass_array = []
mf_array = []
mass_straight = []
mf_array_straight = []

for i in v:
    mf = 1.3816e-7*i**2 - 3.5739e-4*i + 2.65e-3 
    t_derivate = -(2.7632e-4*i - 0.357) 
    mass_array.append(t_derivate)
    mf_array.append(mf)
    
    'Straight line'
    mf_straight = -1.8156e-4*i - 0.0123
    t_straight = 1.8156e-4
    mass_straight.append(t_straight)
    mf_array_straight.append(mf_straight)

'Plotting'
plt.figure(3, figsize=(12, 6))
plt.plot(t, m, label="Mass in tank")
#plt.plot(t, mf_array, 'r', label='Polynomial fitted curve')
plt.plot(t, mf_array_straight, 'r--', label='FFIs straight line fit')
plt.ylabel("Mass [kg]")
plt.xlabel('Time [s]')
#plt.xlim(0, 1000)
#plt.ylim(0, 10)
plt.legend(loc = "upper right", prop={'size': 14})
plt.grid()
plt.title('Test 1: Evolution of mass in tank')
#plt.savefig('Test_1_mass_fitted_curve_with_straight_line')

plt.figure(1, figsize=(12, 6))
plt.plot(t, mass_array, 'b--')
plt.ylabel("Mass flow [kg/s] ")
plt.xlabel('Time [s]')
#plt.xlim(0, 1000)
#plt.ylim(0, 10)
plt.grid()
plt.title('Test 1: Derived mass flow from mass data')
#plt.savefig('Test_1_mass_derived')

'Pressure calculation'
p_atm = 1.0135e5
D = 0.05
A =(np.pi*D**2)/4
rho = 64.3
T = 24.9
L = 42
visc = 13.92e-6
minor_loss = 1
cp = 1.3354e4
epsilon = 0.015*10**-3
RR = epsilon/(D)
const_mass = 0.228

h_l_array = []
dP_array = []


for i in mass_array:
    v = i/(rho*A)
    Re = (rho*v*D)/visc

    f_d = 0.0055*(1+(2e4*RR+(10**6/Re))**(1/3))
    
    Darcy = f_d*L/D*((rho*v**2)/2)
    h_l = (minor_loss*rho*v**2)/2
    P_loss = Darcy + h_l

    h_l_array.append(P_loss)

print(h_l_array)
i = 1
avrg_1 = []
cum_sum = np.cumsum(P)
while i <= len(P):
    window_average_1 = round(cum_sum[i-1] / i, 1)
    avrg_1.append(window_average_1)
    i += 1

'Constant mass flow calculation'
v = const_mass/(rho*A)
Re = (rho*v*D)/visc

f_d = 0.0055*(1+(2e4*RR+(10**6/Re))**(1/3))
    
Darcy = f_d*L/D*((rho*v**2)/2)
h_l = (minor_loss*rho*v**2)/2
P_loss = Darcy + h_l
print(P_loss)

const_plot = np.full((1651), P_loss)

'Plotting'
plt.figure(4, figsize=(12, 6))
plt.plot(t, avrg_1, label='Measured data from FFIs experiment (P01 - P03)')
plt.plot(t, h_l_array, 'r', label = "Calculated pressure loss with varying mass flow")
plt.plot(t, const_plot, 'g--', label='Calculated pressure loss with constant mass flow')
plt.ylabel("Pressure [Pa]")
plt.xlabel('Time [s]')
#plt.xlim(0, 1000)
#plt.ylim(0, 60000)
plt.legend(loc = "upper right", prop={'size': 12})
plt.grid()
plt.title('Test 1: Comparison of calculated pressure loss vs measured data')
#plt.savefig('Test_1_mass_pressure_over_time')

def average(l):
    avg = sum(l)/len(l)
    return avg

calc_average = average(h_l_array)

print('Calculated average is', calc_average)





